@@ -1,4 +1,4 @@
 #ifndef DETECTOR_H
 #define DETECTOR_H
-extern "C" const char * detect (const char * buf, int len);
+const char * run_detector (const char * buf, int len);
 #endif /* ndef DETECTOR_H */
